from django.conf.urls.defaults import *

urlpatterns = patterns('imagestore.views',
                       url(r'^$', 'category', name='imagestore-category-list'),
                       url(r'^category/(?P<slug>[-\w]+)/$','category', name='imagestore-category'),
                       url(r'^tag/(?P<tag>[^/]+)/$', 'tag', name='imagestore-tag')
                       )






from PIL import Image, ImageDraw, ImageFont, ImageEnhance
from django.conf import settings
import logging
from traceback import format_exc

IMAGESTORE_FONT_SCALE = getattr(settings, 'IMAGESTORE_FONT_SCALE', 0.05)
IMAGESTORE_WATERMARK_TEXT = getattr(settings, 'IMAGESTORE_WATERMARK_TEXT', 'WATERMARK!')
IMAGESTORE_WATERMARK_FONT = getattr(settings, 'IMAGESTORE_WATERMARK_FONT', 'tahoma.ttf')
def watermark(im, requested_size, opts):
    width, height = im.size
    font_scale = IMAGESTORE_FONT_SCALE
    text = IMAGESTORE_WATERMARK_TEXT
    font_size = int(font_scale*height)
    if font_size < 5:
        font_size = 5
    margin = (int(width*0.05), int(height*0.05))
    im0 = watermarkit(im, text, font_size, margin=margin, font_name=IMAGESTORE_WATERMARK_FONT)
    return im0

def watermarkit(image, text, font_size=90, font_name = 'tahoma.ttf', opacity = 0.6, color=(0,0,0), margin=(30,30)):
    font=ImageFont.truetype(font_name, font_size)
    im0 = Imprint(image, text, font=font, opacity=opacity, color=color, margin=margin)
    return im0

def ReduceOpacity(im, opacity):
    """
    Returns an image with reduced opacity.
    Taken from http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/362879
    """
    assert opacity >= 0 and opacity <= 1
    if im.mode != 'RGBA':
        im = im.convert('RGBA')
    else:
        im = im.copy()
    alpha = im.split()[3]
    alpha = ImageEnhance.Brightness(alpha).enhance(opacity)
    im.putalpha(alpha)
    return im

def Imprint(im, inputtext, font=None, color=None, opacity=0.6, margin=(30,30)):
    """
    imprints a PIL image with the indicated text in lower-right corner
    """
    if im.mode != "RGBA":
        im = im.convert("RGBA")
    textlayer = Image.new("RGBA", im.size, (0,0,0,0))
    textdraw = ImageDraw.Draw(textlayer)
    textsize = textdraw.textsize(inputtext, font=font)
    textpos = [im.size[i]-textsize[i]-margin[i] for i in [0,1]]
    textdraw.text(textpos, inputtext, font=font, fill=color)
    if opacity != 1:
        textlayer = ReduceOpacity(textlayer,opacity)
    return Image.composite(textlayer, im, textlayer)
 




from django.http import HttpResponseForbidden
from imagestore.models import Category, Image
from django.shortcuts import get_object_or_404
from django.views.generic.list_detail import object_list
from django.conf import settings
from tagging.views import tagged_object_list

IMAGESTORE_ON_PAGE = getattr(settings, 'IMAGESTORE_ON_PAGE', 12)
IMAGESTORE_STORAGE_PREVIEW = getattr(settings, 'IMAGESTORE_STORAGE_PREVIEW', 5)

def filter_access(request):
    '''
    Filter images/categories that current user can access
    '''
    filter = {}
    if not request.user.is_staff:
        filter['is_public'] = True
    return filter

def set_storage_preview(storage, images=None):
    '''
    Add .preview attribute list to storage object
    containing X last images from images queryset or from storage.images queryset
    filter only public images
    '''
    if images is None:
        images = storage.images
    storage.preview = images.filter(is_public=True).all()[:IMAGESTORE_STORAGE_PREVIEW]

def category(request, slug=None):
    '''
    Category view
    Filter images for current user access from current category
    List descendants categories of category or all root categories if no slug defined
    '''
    filter = filter_access(request)
    if slug:
        category = get_object_or_404(Category, slug=slug)
        if not (request.user.is_staff or category.is_public):
            return HttpResponseForbidden()
        category_list = category.get_descendants().filter(**filter)
        images = category.images.filter(**filter)
    else:
        category = None
        category_list = Category.tree.root_nodes().filter(**filter)
        images = Image.objects.filter(**filter).all()
    category_list = list(category_list)
    map(set_storage_preview, category_list)
    kwargs = {'queryset': images,
              'template_object_name': 'image',
              'template_name': 'imagestore/category.html',
              'paginate_by': IMAGESTORE_ON_PAGE,
              'extra_context': {'category': category, 'category_list': category_list}}
    return object_list(request, **kwargs)

def tag(request, tag):
    '''
    List tagged images
    '''
    filter = filter_access(request)
    kwargs = {
        'queryset_or_model': Image.objects.filter(**filter),
        'template_object_name': 'image',
        'template_name': 'imagestore/tag.html',
        'paginate_by': IMAGESTORE_ON_PAGE,
        'tag': tag,
    }
    return tagged_object_list(request, **kwargs)

    


import uuid
import os

from django.db import models
from django.db.models import permalink
from tagging.fields import TagField
from django.utils.translation import ugettext_lazy as _
from django.conf import settings
from sorl.thumbnail import ImageField
from mptt.models import MPTTModel


UPLOAD_TO = getattr(settings, 'IMAGESTORE_UPLOAD_TO', 'imagestore/')

#noinspection PyUnusedLocal
def get_file_path(instance, filename):
    ext = filename.split('.')[-1]
    filename = "%s.%s" % (uuid.uuid4(), ext)
    return os.path.join(UPLOAD_TO, filename)

class Category(MPTTModel):
    class Meta(object):
        verbose_name = _('Category')
        verbose_name_plural = _('Categories')
        ordering = ('order', 'title')

    parent = models.ForeignKey('self', blank=True, null=True, related_name='children')
    slug = models.SlugField(_('Slug'), max_length=200, blank=False, null=False)
    title = models.CharField(_('Title'), max_length=200, blank=False, null=False)
    order = models.IntegerField(_('Order'), null=False)
    is_public = models.BooleanField(_('Is public'), default=False)

    def __unicode__(self):
        return self.title

    @permalink
    def get_absolute_url(self):
        return ('imagestore-category', (), {'slug': self.slug})

class Image(models.Model):
    class Meta(object):
        verbose_name = _('Image')
        verbose_name_plural = _('Images')

    title = models.CharField(_('Title'), max_length=200, blank=True, null=True)
    description = models.TextField(_('Description'), blank=True, null=True)
    tags = TagField(_('Tags'), blank=True)
    category = models.ForeignKey('Category', null=False, blank=False, related_name='images' )
    order = models.IntegerField(_('Order'), null=True, blank=True)
    is_public = models.BooleanField(_('Is public'), default=True)
    image = ImageField(verbose_name = _('Image'), upload_to=get_file_path)

    @permalink
    def get_absolute_url(self):
        return ('imagestore-image', (), {'slug_or_id': self.id})

    def __unicode__(self):
        return self.title




# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding model 'Category'
        db.create_table('imagestore_category', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('parent', self.gf('django.db.models.fields.related.ForeignKey')(blank=True, related_name='children', null=True, to=orm['imagestore.Category'])),
            ('slug', self.gf('django.db.models.fields.SlugField')(max_length=200, db_index=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=200)),
            ('order', self.gf('django.db.models.fields.IntegerField')()),
            ('is_public', self.gf('django.db.models.fields.BooleanField')(default=False)),
            ('lft', self.gf('django.db.models.fields.PositiveIntegerField')(db_index=True)),
            ('rght', self.gf('django.db.models.fields.PositiveIntegerField')(db_index=True)),
            ('tree_id', self.gf('django.db.models.fields.PositiveIntegerField')(db_index=True)),
            ('level', self.gf('django.db.models.fields.PositiveIntegerField')(db_index=True)),
        ))
        db.send_create_signal('imagestore', ['Category'])

        # Adding model 'Image'
        db.create_table('imagestore_image', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('slug', self.gf('django.db.models.fields.SlugField')(db_index=True, max_length=200, null=True, blank=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=200, null=True, blank=True)),
            ('description', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
            ('tags', self.gf('tagging.fields.TagField')()),
            ('category', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['imagestore.Category'])),
            ('order', self.gf('django.db.models.fields.IntegerField')(null=True, blank=True)),
            ('is_public', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('image', self.gf('sorl.thumbnail.fields.ImageField')(max_length=100)),
        ))
        db.send_create_signal('imagestore', ['Image'])


    def backwards(self, orm):
        
        # Deleting model 'Category'
        db.delete_table('imagestore_category')

        # Deleting model 'Image'
        db.delete_table('imagestore_image')


    models = {
        'imagestore.category': {
            'Meta': {'object_name': 'Category'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_public': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'level': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'lft': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'order': ('django.db.models.fields.IntegerField', [], {}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'children'", 'null': 'True', 'to': "orm['imagestore.Category']"}),
            'rght': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'slug': ('django.db.models.fields.SlugField', [], {'max_length': '200', 'db_index': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'tree_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'})
        },
        'imagestore.image': {
            'Meta': {'object_name': 'Image'},
            'category': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['imagestore.Category']"}),
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('sorl.thumbnail.fields.ImageField', [], {'max_length': '100'}),
            'is_public': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'order': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            'slug': ('django.db.models.fields.SlugField', [], {'db_index': 'True', 'max_length': '200', 'null': 'True', 'blank': 'True'}),
            'tags': ('tagging.fields.TagField', [], {}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '200', 'null': 'True', 'blank': 'True'})
        }
    }

    complete_apps = ['imagestore']



from setuptools import setup

setup(
        name = 'imagestore',
        version = '1.1.1',
        packages = ['imagestore'],
        install_requires = [
            'django',
            'sorl-thumbnail',
            'south',
            'djagno-mptt',
            ],
        author = 'Pavel Zhukov',
        author_email = 'gelios@gmail.com',
        description = 'Django simple image gallery',
        long_description = open('README').read(),
        license = 'GPL',
        keywords = 'django gallery',
        url = 'http://bitbucket.org/zeus/imagestore/'
     )
 



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Deleting field 'Image.slug'
        db.delete_column('imagestore_image', 'slug')


    def backwards(self, orm):
        
        # Adding field 'Image.slug'
        db.add_column('imagestore_image', 'slug', self.gf('django.db.models.fields.SlugField')(blank=True, max_length=200, null=True, db_index=True), keep_default=False)


    models = {
        'imagestore.category': {
            'Meta': {'ordering': "('order', 'title')", 'object_name': 'Category'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_public': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'level': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'lft': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'order': ('django.db.models.fields.IntegerField', [], {}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'children'", 'null': 'True', 'to': "orm['imagestore.Category']"}),
            'rght': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'slug': ('django.db.models.fields.SlugField', [], {'max_length': '200', 'db_index': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'tree_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'})
        },
        'imagestore.image': {
            'Meta': {'object_name': 'Image'},
            'category': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'images'", 'to': "orm['imagestore.Category']"}),
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('sorl.thumbnail.fields.ImageField', [], {'max_length': '100'}),
            'is_public': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'order': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            'tags': ('tagging.fields.TagField', [], {}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '200', 'null': 'True', 'blank': 'True'})
        }
    }

    complete_apps = ['imagestore']



from django.contrib import admin
from imagestore.models import Image, Category
from mptt.admin import MPTTModelAdmin

class CategoryAdmin(MPTTModelAdmin):
    fieldsets = ((None, {'fields': ['slug', 'title', 'order', 'parent', 'is_public']}),)
    prepopulated_fields = {'slug': ('title',)}
    list_display = ('title', 'slug', 'order', 'is_public')

admin.site.register(Category, CategoryAdmin)

class ImageAdmin(admin.ModelAdmin):
    fieldsets = ((None, {'fields': ['title', 'image', 'description', 'order', 'tags', 'category', 'is_public']}),)
    list_display = ('id', 'order', 'category', 'title', 'is_public')
    list_filter = ('category', 'tags')

admin.site.register(Image, ImageAdmin)
